<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="649"/>
        <source>Activate task %1</source>
        <translation>Attiva applicazione %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="546"/>
        <source>Application</source>
        <translation>Applicazione</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="580"/>
        <source>To &amp;Desktop</source>
        <translation>Al &amp;desktop</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="583"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Tutti i desktop</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="593"/>
        <source>Desktop &amp;%1</source>
        <translation>Desktop &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="603"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Al desktop corrente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="612"/>
        <source>Move To N&amp;ext Monitor</source>
        <translation>Sposta al monitor &amp;prossimo</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="618"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Sposta al monitor p&amp;recedente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="624"/>
        <source>&amp;Move</source>
        <translation>&amp;Sposta</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="629"/>
        <source>Resi&amp;ze</source>
        <translation>&amp;Ridimensiona</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ssimizza</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="647"/>
        <source>Maximize vertically</source>
        <translation>Massimizza verticalmente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="654"/>
        <source>Maximize horizontally</source>
        <translation>Massimizza orizzontalmente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="662"/>
        <source>&amp;Restore</source>
        <translation>&amp;Ripristina</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="670"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizza</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="678"/>
        <source>Roll down</source>
        <translation>Srotola</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="686"/>
        <source>Roll up</source>
        <translation>Arrotola</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="695"/>
        <source>&amp;Layer</source>
        <translation>&amp;Livello</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="700"/>
        <source>Always on &amp;top</source>
        <translation>Sempre in &amp;primo piano</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="705"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="710"/>
        <source>Always on &amp;bottom</source>
        <translation>Sempre in &amp;secondo piano</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="717"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="86"/>
        <source>Close group</source>
        <translation>Chiudi gruppo</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Impostazioni della barra applicazioni</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Mostra solo finestre del desktop</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Mostra solo finestre dello &amp;schermo del pannello</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Mostra solo finestre minimizzate</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Alza finestre minimizzate sul desktop attuale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="254"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="264"/>
        <source>Comma separated list of window classes</source>
        <translation>Lista di classe di finestra, separata da commata</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="257"/>
        <source>Exclude from taskbar</source>
        <translation>Escludi dalla barra delle applicazioni</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Scorri le finestre con la rotellina</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Raggruppa finestre della stessa applicazione</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Larghezza massima del pulsante</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Rotellina del mouse</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Soglia</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Accosta finestre della stessa classe</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Altezza massima del pulsante</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Usa icone della classe della finestra se disponibile</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Ruota &amp;automaticamente se il pannello è verticale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Mostra popup al passaggio del puntatore</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Stile dei pulsanti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Chiudi con un clic del tasto centrale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Icon and text</source>
        <translation>Icone e testo</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only icon</source>
        <translation>Solo icone</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Only text</source>
        <translation>Solo testo</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Disabled</source>
        <translation>Disabilitata</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Scrolla insù per alzare, in giù per minimizzare</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Scrolla insù per minimizzare, in giù per alzare</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="54"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Scrolla insù per spostare al desktop prossimo, ingiù al precedente</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Scrolla insù per spostare al desktop precedente, ingiù al prossimo</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="60"/>
        <source>Current</source>
        <translation>attuale</translation>
    </message>
</context>
</TS>
